# Gilliam CLI extensions for running on AWS

This extension to *gilliam*'s command-line tool will add three
commands:

* `gilliam aws create` - create a gilliam stage running on AWS
* `gilliam aws status` - show status about the stage
* `gilliam aws destroy` - kill the stage

